@@ -2,9 +2,14 @@ package FBP::ListCtrl;
 
 use Mouse;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 extends 'FBP::Window';
 with    'FBP::Control';
 
+has style => (
+	is  => 'ro',
+	isa => 'Str',
+);
+
 1;
